#include "Key.hpp"
#include "EpsonScan2.h"

namespace epsonscan {

	class SkipBlankPageOnOff : public Key<SDIInt> 
	{
		public:

		explicit SkipBlankPageOnOff(IKeyDataProvider* dataProvider) : Key<SDIInt>(dataProvider) 
		{

		}

		std::string GetName() const override 
		{
			return std::string(kSDIBlankPageSkipKey);
		}

		void SetValue(const SDIInt& intVal) override
        {   
            current_ = intVal;
        }

		void GetValue(SDIInt& outIntVal) override
        {
            outIntVal = current_;
        }

		void GetCapability(SDICapability &capability) override
        {
            	SetDefaultListCapability(capability);

				bool hasAdf = false;

				ESIndexSet functionalUnits = dataProvider_->GetScanner().get()->GetSupportedFunctionalUnit();
				if (functionalUnits.find(kESFunctionalUnitDocumentFeeder) != functionalUnits.end())
				{
					hasAdf = true;
				}

				if (DTR::IsDTRAvailable() && hasAdf)
				{	
					capability.supportLevel = kSDISupportLevelAvailable;	
				}else{
					capability.supportLevel = kSDISupportLevelNone;
				}
        }

		void Reset() override
        {
            current_ = 0;
        }

		ESDictionary GetEngineKeyValues() override
        {
            auto dict =  ESDictionary();
            return dict;
        }
	};

}//namespace epsonscan