//  detectionareamaxdoublespinbox.cpp -- template and derived ESC/I ESC/I-2 protocol commands
//  Copyright (C) 2018-2019  SEIKO EPSON CORPORATION
//
//  License: GPL-3.0+
//  Author : SEIKO EPSON CORPORATION
//
//  This file is part of the 'Epson Scan 2' package.
//  This package is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License or, at
//  your option, any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//  You ought to have received a copy of the GNU General Public License
//  along with this package.  If not, see <http://www.gnu.org/licenses/>.

#include "mainwindow.h"

DetectionAreaMaxDoubleSpinBox::DetectionAreaMaxDoubleSpinBox(QWidget *parent) :
    QDoubleSpinBox(parent)
{
    base_value = 1550;
    this->CreateBaseToValue();
}

void DetectionAreaMaxDoubleSpinBox::initialize(SDIInt default_value)
{
    base_value = default_value;
    this->CreateBaseToValue();

    this->SetSpinBoxParam();

    if(this->isUnit_inchi()){
        this->setValue(CreateDisplayValue(current_value_inchi));
    }else {
        this->setValue(CreateDisplayValue(current_value_mm));
    }
}

void DetectionAreaMaxDoubleSpinBox::Finalize(void)
{
    this->CreateValueToBase();
    this->CreateBaseToValue();
}

void DetectionAreaMaxDoubleSpinBox::SetSpinBoxParam(void)
{
    if(this->isUnit_inchi()){
        this->setDecimals(1);
        this->setSingleStep(0.1);

        this->setMaximum(15.5);
        this->setMinimum(1.0);
    }else {
        this->setDecimals(0);
        this->setSingleStep(1);

        this->setMaximum(393);
        this->setMinimum(26);
    }
}

void DetectionAreaMaxDoubleSpinBox::CreateBaseToValue(void)
{
    current_value_inchi = base_value / 100;
    current_value_mm = base_value * 25.4 / 100;
}

void DetectionAreaMaxDoubleSpinBox::CreateValueToBase(void)
{
    if(this->isUnit_inchi()){
        if(CreateDisplayValue(current_value_inchi) != CreateDisplayValue(this->value())){
            current_value_inchi = this->value();
            base_value =  (current_value_inchi * 100) + 0.005;
        }
    }else { //mm
        if(CreateDisplayValue(current_value_mm) != CreateDisplayValue(this->value())){
            current_value_mm = this->value();
            base_value =  (current_value_mm * 100 / 25.4) + 0.005;
        }
    }
}

double DetectionAreaMaxDoubleSpinBox::CreateDisplayValue(double value)
{
    int magnification;
    int temp;
    if(this->isUnit_inchi()){
        magnification = 100;
        temp = value * magnification;
    }else {
        magnification = 10;
        temp = value * magnification;
    }
    return (double)temp / (double)magnification;
}

void DetectionAreaMaxDoubleSpinBox::set_enabled(bool enabled)
{
    this->setEnabled(enabled);
}

bool DetectionAreaMaxDoubleSpinBox::isUnit_inchi(void)
{
    Configuration& config = Configuration::GetConfiguration();
    Units units = config.config_para.units;

    if(units == unit_inchi){
        return true;
    }else if(units == unit_mm){
        return false;
    }else {
        return false;
    }
}

void DetectionAreaMaxDoubleSpinBox::setMinValue(double value){

    if(value < 0){
        value = 0;
    }
    double dif = 0;
    if(this->isUnit_inchi()){
        dif = 1.0;
    }else { //mm
        dif = 26;
    }
    this->setMinimum(value + dif);
}
